@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2019 Laurent Montel <montel@kde.org>
+ * Copyright (C) 2019-2020 Laurent Montel <montel@kde.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -26,11 +26,10 @@
 #include <QVBoxLayout>
 #include <QPushButton>
 
-#include <kconfig.h>
-#include <kconfiggroup.h>
+#include <KConfig>
+#include <KConfigGroup>
 #include <QDialogButtonBox>
 #include <QHBoxLayout>
-#include <kiconloader.h>
 #include <KLocalizedString>
 #include <KMessageBox>
 
@@ -92,7 +91,6 @@ LdapConfigureWidget::LdapConfigureWidget(QWidget *parent)
 
     connect(mUpButton, &QToolButton::clicked, this, &LdapConfigureWidget::slotMoveUp);
     connect(mDownButton, &QToolButton::clicked, this, &LdapConfigureWidget::slotMoveDown);
-
 }
 
 LdapConfigureWidget::~LdapConfigureWidget()
@@ -143,7 +141,7 @@ void LdapConfigureWidget::slotEditHost()
 
     KLDAP::LdapServer server = item->server();
     KLDAP::AddHostDialog dlg(&server, this);
-    dlg.setWindowTitle(i18n("Edit Host"));
+    dlg.setWindowTitle(i18nc("@title:window", "Edit Host"));
 
     if (dlg.exec() && !server.host().isEmpty()) {   //krazy:exclude=crashy
         item->setServer(server);
@@ -324,20 +322,17 @@ void LdapConfigureWidget::initGUI()
     mUpButton = new QToolButton(upDownBox);
     upDownBoxVBoxLayout->addWidget(mUpButton);
     mUpButton->setIcon(QIcon::fromTheme(QStringLiteral("go-up")));
-    mUpButton->setIconSize(QSize(KIconLoader::SizeSmall, KIconLoader::SizeSmall));
     mUpButton->setEnabled(false);   // b/c no item is selected yet
 
     mDownButton = new QToolButton(upDownBox);
     upDownBoxVBoxLayout->addWidget(mDownButton);
     mDownButton->setIcon(QIcon::fromTheme(QStringLiteral("go-down")));
-    mDownButton->setIconSize(QSize(KIconLoader::SizeSmall, KIconLoader::SizeSmall));
     mDownButton->setEnabled(false);   // b/c no item is selected yet
 
     QWidget *spacer = new QWidget(upDownBox);
     upDownBoxVBoxLayout->addWidget(spacer);
     upDownBoxVBoxLayout->setStretchFactor(spacer, 100);
 
-
     QDialogButtonBox *buttons = new QDialogButtonBox(this);
     QPushButton *add = buttons->addButton(i18n("&Add Host..."),
                                           QDialogButtonBox::ActionRole);
