@@ -7,7 +7,7 @@
   Copyright (c) 2001 Waldo Bastian <bastian@kde.org>
   Copyright (c) 2004 Daniel Molkentin <danimo@klaralvdalens-datakonsult.se>
   Copyright (c) 2004 Karl-Heinz Zimmer <khz@klaralvdalens-datakonsult.se>
-  Copyright (C) 2017-2019 Laurent Montel <montel@kde.org>
+  Copyright (C) 2017-2020 Laurent Montel <montel@kde.org>
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
@@ -35,7 +35,7 @@
 
 #include <Job>
 #include <QUrl>
-#include <kconfiggroup.h>
+#include <KConfigGroup>
 
 #include <KEmailAddress>
 #include <KColorScheme>
@@ -887,7 +887,8 @@ KLDAP::LdapClientSearch *AddresseeLineEdit::ldapSearch() const
 
 void AddresseeLineEdit::slotEditingFinished()
 {
-    for (KJob *job : d->mightBeGroupJobs()) {
+    const QList<KJob *> listJob = d->mightBeGroupJobs();
+    for (KJob *job : listJob) {
         disconnect(job);
         job->deleteLater();
     }
